@@ -15,6 +15,7 @@ from magicapi.Decorators.parse_objects import parse_objects
 # from magicapi import settings
 from magicapi import g
 
+
 class Error(BaseModel):
     error_class: str
     error_dict: Any
@@ -123,15 +124,7 @@ def safe_loads(body):
     return None
 
 
-async def make_call_from_request_and_response(
-    request: FastAPIRequest,
-    response: Optional[FastApiResponse],
-    error: Optional[Exception],
-    times_dict: dict,
-):
-    if not g.settings.save_calls:
-        return
-
+async def make_request_obj_from_request(request: FastAPIRequest):
     body = await get_request_body(request)
     jsonable_body = make_body_jsonable(body)
 
@@ -149,6 +142,19 @@ async def make_call_from_request_and_response(
         scheme=request.url.scheme,
         port=request.url.port,
     )
+    return request_obj
+
+
+async def make_call_from_request_and_response(
+        request: FastAPIRequest,
+        response: Optional[FastApiResponse],
+        error: Optional[Exception],
+        times_dict: dict,
+):
+    if not g.settings.save_calls:
+        return
+
+    request_obj = await make_request_obj_from_request(request)
 
     response_obj = (
         None
